@@ -22,12 +22,13 @@ from collections import OrderedDict, defaultdict, deque
 from pathlib import Path
 
 import attr
+from git import NULL_TREE
 
 from renku.core import errors
+from renku.core.commands.client import pass_local_client
 from renku.core.models.entities import Collection, Entity
 from renku.core.models.git import Range
-from renku.core.models.provenance.activities import Activity, ProcessRun, Usage
-from renku.core.models.provenance.processes import Process
+from renku.core.models.provenance.activities import Activity, ProcessRun, Usage, WorkflowRun
 from renku.core.models.provenance.qualified import Generation
 from renku.core.models.workflow.run import Run
 
@@ -63,11 +64,12 @@ class Graph(object):
     _latest_commits = attr.ib(default=attr.Factory(dict))
     _nodes = attr.ib()
     _need_update = attr.ib(default=attr.Factory(dict))
+    _workflows = attr.ib(default=attr.Factory(dict))
 
     cwl_prefix = attr.ib(init=False)
 
     def __attrs_post_init__(self):
-        """Derive basic informations."""
+        """Derive basic information."""
         self.cwl_prefix = self.client.cwl_prefix
 
     @_nodes.default
@@ -147,9 +149,10 @@ class Graph(object):
         elif isinstance(node, Entity):
             # Link files and directories and generations.
             return ([node.parent] if node.parent is not None else []) + _from_entity(node, check_parents=False)
-        elif isinstance(node, Process) or isinstance(node, Run):
+        elif isinstance(node, Run):
             # warnings.warn('Called on run {0}'.format(node), stacklevel=2)
-            return self.parents(node.activity)
+            activity = node.activity
+            return self.parents(activity) if activity else []
         elif isinstance(node, ProcessRun):
             return node.qualified_usage
         elif isinstance(node, Activity):
@@ -252,9 +255,11 @@ class Graph(object):
 
             # Iterate over parents.
             if isinstance(activity, ProcessRun):
+                if isinstance(activity, WorkflowRun):
+                    self._workflows[activity.path] = activity
                 for entity in activity.qualified_usage:
                     for member in entity.entities:
-                        parent_activities = self.client.activities_for_paths(member.path, revision="HEAD")
+                        parent_activities = self.client.activities_for_paths(paths=[member.path], revision="HEAD")
                         for a in parent_activities:
                             if a.commit and a.commit not in visited:
                                 self.activities[a.commit] = a
@@ -381,7 +386,7 @@ class Graph(object):
         """Return siblings for a given node.
 
         The key is part of the result set, hence to check if the node has
-        siblings you should check the lenght is greater than 1.
+        siblings you should check the length is greater than 1.
         """
         parent = None
 
@@ -394,7 +399,7 @@ class Graph(object):
             parent = node.activity
         elif isinstance(node, Usage):
             parent = self.activities[node.commit]
-        elif isinstance(node, Process) or isinstance(node, Run):
+        elif isinstance(node, Run):
             return {node}
 
         if parent is None or not isinstance(parent, ProcessRun):
@@ -408,13 +413,7 @@ class Graph(object):
     def as_workflow(
         self, input_paths=None, output_paths=None, outputs=None, use_latest=True,
     ):
-        """Serialize graph to renku ``Run`` workflow.
-
-        :param global_step_outputs: Make all step outputs global.
-        """
-        if output_paths is None:
-            output_paths = {node.path for node in outputs if _safe_path(node.path)}
-
+        """Serialize graph to renku ``Run`` workflow."""
         processes = set()
         stack = []
 
@@ -473,10 +472,66 @@ class Graph(object):
                         stack.append(process_run)
                         processes.add(process_run)
 
+        if len(processes) == 1:
+            process_run = list(processes)[0]
+            if not isinstance(process_run, WorkflowRun):
+                return process_run.association.plan
+
         parent_process = Run(client=self.client)
 
         for step in processes:
             # Loop through runs and add them as sub processes to parent.
             parent_process.add_subprocess(step.association.plan)
 
-        return parent_process
+        return self._find_identical_parent_run(run=parent_process, outputs=outputs)
+
+    def _find_identical_parent_run(self, run, outputs):
+        from marshmallow.exceptions import ValidationError
+
+        def workflow_has_identical_subprocesses(workflow_, subprocesses_ids_):
+            wf_subprocesses_ids = [step.process._id for step in workflow_.association.plan.subprocesses]
+            return wf_subprocesses_ids == subprocesses_ids_
+
+        subprocesses_ids = [step.process._id for step in run.subprocesses]
+        for workflow in self._workflows.values():
+            if workflow_has_identical_subprocesses(workflow, subprocesses_ids):
+                return workflow.association.plan
+
+        # Search all workflow files that generate the same outputs to find a similar parent run
+        workflow_files = set()
+        for output in outputs:
+            activities = self.client.path_activity_cache.get(output.path, {}).values()
+            workflow_files |= set([file for activity in activities for file in activity])
+        for file_ in workflow_files:
+            try:
+                workflow = WorkflowRun.from_yaml(path=file_, client=self.client)
+            except ValidationError:  # Not a WorkflowRun
+                pass
+            else:
+                if workflow_has_identical_subprocesses(workflow, subprocesses_ids):
+                    return workflow.association.plan
+
+        return run
+
+
+@pass_local_client(requires_migration=True)
+def build_graph(client, revision, no_output, paths):
+    """Build graph structure."""
+    graph = Graph(client)
+    if not paths:
+        start, is_range, stop = revision.partition("..")
+        if not is_range:
+            stop = start
+        elif not stop:
+            stop = "HEAD"
+
+        commit = client.repo.rev_parse(stop)
+        paths = (
+            str(client.path / item.a_path)
+            for item in commit.diff(commit.parents or NULL_TREE)
+            # if not item.deleted_file
+        )
+
+    # NOTE shall we warn when "not no_output and not paths"?
+    graph.build(paths=paths, revision=revision, can_be_cwl=no_output)
+    return graph
