@@ -417,3 +417,12 @@ class InvalidTemplateError(RenkuException):
 
 class ExportError(RenkuException):
     """Raised when a dataset cannot be exported."""
+
+
+class RenkuImportError(RenkuException):
+    """Raised when a dataset cannot be imported."""
+
+    def __init__(self, exp, msg):
+        """Embed exception and build a custom message."""
+        self.exp = exp
+        super(RenkuImportError, self).__init__(msg)
