@@ -251,7 +251,7 @@ class DatasetsApiMixin(object):
             )
         else:
             for url in urls:
-                is_remote, is_git = _check_url(url)
+                is_remote, is_git, url = _check_url(url)
 
                 if is_git and is_remote:  # Remote git repo
                     sources = sources or ()
@@ -444,7 +444,6 @@ class DatasetsApiMixin(object):
                 return [{"path": path_in_repo, "source": path_in_repo, "parent": self}]
 
         action = "symlink" if external else "copy"
-
         return [
             {
                 "path": dst.relative_to(self.path),
@@ -549,6 +548,8 @@ class DatasetsApiMixin(object):
         paths = {f[0] for f in files}
         metadata = self._fetch_files_metadata(remote_client, paths)
 
+        new_files = []
+
         for path, src, dst in files:
             if not src.is_dir():
                 # Use original metadata if it exists
@@ -562,6 +563,11 @@ class DatasetsApiMixin(object):
 
                 path_in_dst_repo = dst.relative_to(self.path)
 
+                if path_in_dst_repo in new_files:  # A path with the same destination is already copied
+                    continue
+
+                new_files.append(path_in_dst_repo)
+
                 if remote_client._is_external_file(src):
                     operation = (src.resolve(), dst, "symlink")
                 else:
@@ -596,7 +602,9 @@ class DatasetsApiMixin(object):
 
     def _provider_check(self, url):
         """Check additional provider related operations."""
-        url = parse.urlparse(url)
+        # NOTE: Check if the url is a redirect.
+        r = requests.head(url, allow_redirects=True)
+        url = parse.urlparse(r.url)
 
         if "dropbox.com" in url.netloc:
             url = self._ensure_dropbox(url)
@@ -611,7 +619,8 @@ class DatasetsApiMixin(object):
             result[r] = None
         return result
 
-    def _resolve_path(self, root_path, path):
+    @staticmethod
+    def _resolve_path(root_path, path):
         """Check if a path is within a root path and resolve it."""
         try:
             root_path = Path(root_path).resolve()
@@ -620,8 +629,10 @@ class DatasetsApiMixin(object):
         except ValueError:
             raise errors.ParameterError("File {} is not within path {}".format(path, root_path))
 
-    def _get_src_and_dst(self, path, repo_path, sources, dst_root, used_sources):
+    @staticmethod
+    def _get_src_and_dst(path, repo_path, sources, dst_root, used_sources):
         is_wildcard = False
+        matched_pattern = None
 
         if not sources:
             source = Path(".")
@@ -633,19 +644,25 @@ class DatasetsApiMixin(object):
                 except ValueError:
                     if glob.globmatch(path, str(s), flags=glob.GLOBSTAR):
                         is_wildcard = True
-                        source = path
+                        source = Path(path)
                         used_sources.add(s)
+                        matched_pattern = str(s)
                         break
                 else:
-                    source = s
+                    source = Path(s)
                     used_sources.add(source)
                     break
 
             if not source:
                 return
 
+        if is_wildcard:
+            # Search to see if a parent of the path matches the pattern and return it
+            while glob.globmatch(str(source.parent), matched_pattern, flags=glob.GLOBSTAR) and source != source.parent:
+                source = source.parent
+
         src = repo_path / path
-        source_name = Path(source).name
+        source_name = source.name
         relative_path = Path(path).relative_to(source)
 
         if src.is_dir() and is_wildcard:
@@ -654,9 +671,10 @@ class DatasetsApiMixin(object):
 
         dst = dst_root / source_name / relative_path
 
-        return (path, src, dst)
+        return path, src, dst
 
-    def _fetch_lfs_files(self, repo_path, paths):
+    @staticmethod
+    def _fetch_lfs_files(repo_path, paths):
         """Fetch and checkout paths that are tracked by Git LFS."""
         repo_path = str(repo_path)
         try:
@@ -1067,7 +1085,7 @@ class DatasetsApiMixin(object):
         tmp_root.mkdir(parents=True, exist_ok=True)
         tmp = tempfile.mkdtemp(dir=tmp_root)
 
-        with requests.get(url, stream=True) as request:
+        with requests.get(url, stream=True, allow_redirects=True) as request:
             request.raise_for_status()
 
             if not filename:
@@ -1120,6 +1138,10 @@ def _check_url(url):
 
     if is_remote:
         is_git = u.path.endswith(".git")
+        if not is_git:
+            # NOTE: Check if the url is a redirect.
+            url = requests.head(url, allow_redirects=True).url
+            u = parse.urlparse(url)
     else:
         try:
             Repo(u.path, search_parent_directories=True)
@@ -1128,7 +1150,7 @@ def _check_url(url):
         else:
             is_git = True
 
-    return is_remote, is_git
+    return is_remote, is_git, url
 
 
 DATASET_METADATA_PATHS = [
