@@ -16,7 +16,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Dataverse unit tests."""
+import pytest
+
 from renku.core.commands.providers.dataverse import DataverseExporter, _DataverseDeposition
+from renku.core.commands.providers.doi import DOIProvider
+from renku.core.errors import RenkuImportError
 
 
 def test_dataverse_exporter_init():
@@ -36,3 +40,27 @@ def test_dataverse_deposition_init():
     assert "let-me-in" == deposit.access_token
     assert "http://sss" == deposit.server_url
     assert not deposit.dataset_pid
+
+
+def test_doi_serializer():
+    """Check doi serialization."""
+    data = {
+        "id": 1,
+        "doi": "doi@doi.35446",
+        "url": "https://doi.org/35446",
+        "type": "dataset",
+        "categories": [1, 2, 3],
+        "author": "myname",
+        "contributor": "mycontributor",
+        "version": 34,
+        "issued": "15.09.2020",
+        "title": "my title",
+        "abstract": "my awesome dataset",
+        "language": "english",
+        "publisher": "me",
+        "container-title": "yes",
+        "missing": True,
+    }
+
+    with pytest.raises(RenkuImportError):
+        DOIProvider._serialize(data)
