@@ -414,7 +414,29 @@ def test_list_datasets_view(svc_client_with_repo):
     assert {"datasets"} == set(response.json["result"].keys())
     assert 0 != len(response.json["result"]["datasets"])
 
-    assert {"version", "description", "created_at", "name", "title", "creators", "keywords"} == set(
+    assert {"version", "description", "identifier", "created_at", "name", "title", "creators", "keywords"} == set(
+        response.json["result"]["datasets"][0].keys()
+    )
+
+
+@pytest.mark.service
+@pytest.mark.integration
+@flaky(max_runs=30, min_passes=1)
+def test_list_datasets_view_remote(svc_client_with_repo, it_remote_repo):
+    """Check listing of existing datasets."""
+    svc_client, headers, _, _ = svc_client_with_repo
+
+    params = dict(git_url=it_remote_repo)
+
+    response = svc_client.get("/datasets.list", query_string=params, headers=headers,)
+
+    assert response
+    assert_rpc_response(response)
+
+    assert {"datasets"} == set(response.json["result"].keys())
+    assert 0 != len(response.json["result"]["datasets"])
+
+    assert {"version", "description", "identifier", "created_at", "name", "title", "creators", "keywords"} == set(
         response.json["result"]["datasets"][0].keys()
     )
 
@@ -436,6 +458,26 @@ def test_list_datasets_view_no_auth(svc_client_with_repo):
     assert_rpc_response(response, with_key="error")
 
 
+@pytest.mark.service
+@pytest.mark.integration
+@flaky(max_runs=30, min_passes=1)
+def test_list_datasets_files_remote(svc_client_with_repo, it_remote_repo):
+    """Check listing of existing dataset files."""
+    svc_client, headers, _, _ = svc_client_with_repo
+
+    params = dict(git_url=it_remote_repo, name="ds1")
+
+    response = svc_client.get("/datasets.files_list", query_string=params, headers=headers,)
+
+    assert response
+    assert_rpc_response(response)
+
+    assert {"files", "name"} == set(response.json["result"].keys())
+
+    assert 0 != len(response.json["result"]["files"])
+    assert "ds1" == response.json["result"]["name"]
+
+
 @pytest.mark.service
 @pytest.mark.integration
 @flaky(max_runs=10, min_passes=1)
@@ -463,10 +505,9 @@ def test_create_and_list_datasets_view(svc_client_with_repo):
 
     assert response
     assert_rpc_response(response)
-
     assert {"datasets"} == set(response.json["result"].keys())
     assert 0 != len(response.json["result"]["datasets"])
-    assert {"creators", "name", "version", "title", "description", "created_at", "keywords"} == set(
+    assert {"creators", "name", "identifier", "version", "title", "description", "created_at", "keywords"} == set(
         response.json["result"]["datasets"][0].keys()
     )
 
@@ -518,14 +559,14 @@ def test_list_dataset_files(svc_client_with_repo):
     }
 
     response = svc_client.get("/datasets.files_list", query_string=params, headers=headers,)
-
     assert response
-    assert_rpc_response(response)
 
+    assert_rpc_response(response)
     assert {"name", "files"} == set(response.json["result"].keys())
 
     assert params["name"] == response.json["result"]["name"]
     assert file_name in [file["name"] for file in response.json["result"]["files"]]
+    assert {"name", "path", "added"} == response.json["result"]["files"][0].keys()
 
 
 @pytest.mark.service
